# Copyright 2008 Antoine Lefebvre
#
# This file is part of "The Wind Instrument Acoustic Toolkit".
#
# "The Wind Instrument Acoustic Toolkit" is free software:
# you can redistribute it and/or modify it under the terms of
# the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# "The Wind Instrument Acoustic Toolkit" is distributed in the hope
# that it will be useful, but WITHOUT ANY WARRANTY; without even
# the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with "The Wind Instrument Acoustic Toolkit".
# If not, see <http://www.gnu.org/licenses/>.
#
# All rights reserved.

""" Plot.py - Classes for plotting standard impedance plots are defined here.
    
    TODO: cleanup, redesign and maybe elimination.
"""

__all__ = ['ImpedancePlot']

import numpy
import pylab

LINESTYLES = ('-', '--', '-.', ':', '.', ',', 'o')
CUSTOMDASHES = ((None,None), (5,2), (4,2,1,1), (2,2))
COLORS = ('blue', 'red', 'green')

class ImpedancePlot:
    " Class for generating standard impedance plot with pylab "
    def __init__(self, title_string, listtoplot, maximalists=None):
        self.title_string = title_string
        self.listtoplot = listtoplot
        self.maximalists = maximalists
        self.basefilename = self.title_string.replace(" ","")
        self.pngfilename = self.basefilename + '.png'
        self.pdffilename = self.basefilename + '.pdf'
        
    def plot(self, style='lin', title=True, fsize=(20,12), xlim=(100,4500)):
        """ Plot the figure.

            You have to do a pylab.show() to see it.
        """
        self.fig = pylab.figure(figsize=fsize)

        if style is 'dB':
            func = lambda x: 20*numpy.log10(x)
        else:
            func = lambda x: x
        i = 0
        for data in self.listtoplot:
            f,z,lbl = data
            lines = pylab.semilogx(f, func(numpy.abs(z)), LINESTYLES[i],
                                   color=COLORS[i], label=lbl)
            lines[0].set_dashes(CUSTOMDASHES[i])
            i = i+1

        if self.maximalists is not None:
            for ml in self.maximalists:
                print ml
                for f, z in ml:
                    pylab.semilogx([f], func([z]), 'ok')
                    
        if title:
            pylab.title(self.title_string)

        pylab.xlabel('Frequency [Hz]')
        if style is 'dB':
            pylab.ylabel('Normalized impedance (dB): 20log10(Z/Zc)')
        else:
            pylab.ylabel('Normalized impedance Z/Zc')
        pylab.legend()
        pylab.grid(True)
        self.fig.axes[0].xaxis.grid(True, which='minor')
        pylab.xlim(xlim)

    def save(self, filename=None):
        """ Save the figure to a file. 

            the file name is made from the figure title if not provided.
        """
        if filename is None:
            filename = self.basefilename
        print 'saving ' + filename
        pylab.savefig(filename)

#    def htmlInclude(self,f):
#        print >>f, "<a href=\"%s\"> Graphic of %s </a>"%
#(self.pngfilename,self.descriptionString)


