# Copyright 2008 Antoine Lefebvre
#
# This file is part of "The Wind Instrument Acoustic Toolkit".
#
# "The Wind Instrument Acoustic Toolkit" is free software:
# you can redistribute it and/or modify it under the terms of
# the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# "The Wind Instrument Acoustic Toolkit" is distributed in the hope
# that it will be useful, but WITHOUT ANY WARRANTY; without even
# the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with "The Wind Instrument Acoustic Toolkit".
# If not, see <http://www.gnu.org/licenses/>.
#
# All rights reserved.

""" Reports.py - Classes and functions to generate text, html and latex reports

    logilab.common have some classes for reporting in text, html, docbook.
    we might use their stuff here....

"""

__all__ = ['ImpedanceMaximaListing', 'ImpedanceMaximaComparison', 
           'MeasurementDataDescription','WebPage']

import numpy

class LatexTable:
    def _write_table_beginning(self,f):
        print >>f, "\\begin{table}[ht]"
        print >>f, "\\caption{%s}"%self.title
        print >>f, "\\begin{tabular}{|r|r|r|r|r|r|r|}"
        print >>f, "\hline"
        
    def _write_table_ending(self,f):
        print >>f, "\hline"
        print >>f, "\\end{tabular}"
        print >>f, "\\end{table}"
        
    def _write_table_data(self, f):
        for row in self.data:
            i = 0
            for cell in row:
                if i != 0: 
                    f.write(" & ")
                if type(cell) is numpy.float64:
                    f.write("%.2f"%cell)
                else:
                    f.write("%s"%cell)
                i = i + 1
            f.write("\\\\\n")
            
    def latex_export(self, f):
        LatexTable._write_table_beginning(self, f)
        self._write_latextable_titles(f)
        LatexTable._write_table_data(self, f)
        LatexTable._write_table_ending(self, f)

td = "<td align=\"right\" >"
    
class HtmlTable:
    def _write_table_beginning(self, f):
        print >>f, "<table frame=\"box\" rules=\"group\">"
        print >>f, "<caption><em>%s</em></caption>"%self.title

    def _write_table_ending(self, f):
        print >>f, "</table>"

    
#    def tableData(self,f):
#        for d in self.data:            
#        td = "<td align=\"right\" >"
#        for (f1, f2, cents, A1, A2, dB, r1, r2) in self.data:
#            print >>f, "<tr>" + td + "%.2f (%.3f)"%(f1,r1) + td + 
# "%.2f (%.3f)"%(f2,r2) + td + "%.2f"%cents + td + "%.2f"%A1 + td + 
# "%.2f"%A2 + td + "%.2f"%dB
            
#            for i in d:
#                if type(i) is numpy.float64 or float:
#                    print >>f, "<td align=\"right\" >", "%.2f"%i
#                else:
#                    print >>f, "<td align=\"right\" >", i

    def html_export(self, f):
        HtmlTable._write_table_beginning(self, f)
        self._write_htmltable_titles(f)
        self._write_table_data(f)
        HtmlTable._write_table_ending(self, f)


    
class ImpedanceMaximaListing(HtmlTable):
    def __init__(self, title, data):
        self.title = title
        self.data = data #ProcessMaximas( object.getMaximaData() )

    def _write_htmltable_titles(self, f):
        print >>f, "<tr><th>Maxima frequency [Hz] <th>Maxima magnitude",\
                   "<th> Frequency ratio fn/f1"

    def _write_table_data(self, f):
        fudamental_frequency = self.data[0][0]
        for f1, A1 in self.data:
            print >>f, "<tr>" + td + "%.2f"%f1 + td +"%.2f"%A1 + td +\
                       "%.3f"%f1/fudamental_frequency
            
#                if type(i) is numpy.float64 or float:
#                    print >>f, "<td align=\"right\" >", "%.2f"%i
#                else:
#                    print >>f, "<td align=\"right\" >", i
                    
        
class ImpedanceMaximaComparison(HtmlTable, LatexTable):
    def __init__(self, title, comparison):
        self.title = title
        self.data = comparison 

    def _write_htmltable_titles(self, f):
        print >>f, "<tr><th colspan=\"2\">Maxima frequency [Hz] (Ratio fn/f1)",\
                   "<th rowspan=\"2\"> Interval [cents] <th colspan=\"2\">",\
                   "Maxima magnitudes <th rowspan=\"2\"> Ratio [db]"
        print >>f, "<tr><th>Theoretical <th>Experimental <th> Theoretical",\
                   "<th>Experimental"

    def _write_latextable_titles(self, f):
        print >>f, "\\multicolumn{2}{|c|}{Maxima frequency [Hz] (fn/f1)} &",\
                   " Interval [cents] &",\
                   " \\multicolumn{3}{|c|}{Maxima magnitudes} & \\\\"
        print >>f, "\\cline{1-2}\\cline{4-5}"
        print >>f, "Theoretical & Experimental & & Theoretical &",\
                   " Experimental & Ratio [db] & \\\\"
        print >>f, "\\hline \\hline"

    def _write_table_data(self, f):
        for f1,f2,cents,A1,A2,dB,r1,r2 in self.data:
            print >>f, "<tr>" + td + "%.2f (%.3f)"%(f1,r1) + td +\
                       "%.2f (%.3f)"%(f2,r2) + td + "%.2f"%cents + td +\
                       "%.2f"%A1 + td + "%.2f"%A2 + td + "%.2f"%dB

                        
class MeasurementDataDescription(HtmlTable):
    def __init__(self, title, objects):
        self.title = title
        self.data = objects

    def _write_htmltable_titles(self, f):
        return

    def _write_table_data(self, f):
        for d in self.data:
            print >>f, "<tr>"
            for i in d:
                print >>f, "<td align=\"right\" >", i
#                if type(i) is numpy.float64 or float:
#                    print >>f, "<td align=\"right\" >", "%.2f"%i
#                else:
#                    print >>f, "<td align=\"right\" >", i    
    
class WebPage:
    def __init__(self, filename):
        self.file = open(filename, 'w')

    def add_link(self, path, string):
        self.write("<a href=\"%s\">%s</a>"%(path, string))

    def add_image(self, path, string):
        self.write("<img href=\"%s\">%s</a>"%(path, string))

    def add_rule(self):
        self.write("<hr />")

    def add_anchor(self, name):
        self.write("<a name=\"%s\"></a>"%name)

    def write(self, string):
        print >>self.file, string

    def close(self):
        self.file.close()        
