# Copyright 2008 Antoine Lefebvre
#
# This file is part of "The Wind Instrument Acoustic Toolkit".
#
# "The Wind Instrument Acoustic Toolkit" is free software:
# you can redistribute it and/or modify it under the terms of
# the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# "The Wind Instrument Acoustic Toolkit" is distributed in the hope
# that it will be useful, but WITHOUT ANY WARRANTY; without even
# the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with "The Wind Instrument Acoustic Toolkit".
# If not, see <http://www.gnu.org/licenses/>.
#
# All rights reserved.

""" Functions.py - Definition of various useful functions

"""

import numpy
from wiat.util import calculate_interval_in_cents, calculate_ratio_in_db
from wiat.TM import CalculateImpedance

__all__ = ['CompareMaxima','calculate_impulse_response']

def CompareMaxima(ml1,ml2):
    " Compare two list of maxima data. "
    l1 = len(ml1)
    l2 = len(ml2)
    comp = []
    for i in range(min([l1,l2])):
        (f1,A1) = ml1[i]
        (f2,A2) = ml2[i]
        if i == 0:
            fund1 = f1
            fund2 = f2
        cents = calculate_interval_in_cents(f1,f2)
        dB = calculate_ratio_in_db(A1,A2)
        comp.append((f1, f2, cents, A1, A2, dB, f1/fund1, f2/fund2))
    return comp

def calculate_impulse_response(I,T,N,fs):
    """ Calculate the impulse response of an instrument from its impedance.

        I: Instrument instance
        T: temperature
        N: size of the fft
        fs: sampling frequency
    """
    f = numpy.abs(numpy.fft.fftfreq(N)[1:N/2+1])*fs
    Z = CalculateImpedance(I,f,T)
    H = numpy.concatenate(([numpy.complex(0.)], Z, numpy.conj((Z[0:-1]))))
    h = numpy.real(numpy.fft.ifft(H))
    return h
