# coding: latin-1
#
# Copyright 2008 Antoine Lefebvre
#
# This file is part of "The Wind Instrument Acoustic Toolkit".
#
# "The Wind Instrument Acoustic Toolkit" is free software:
# you can redistribute it and/or modify it under the terms of
# the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# "The Wind Instrument Acoustic Toolkit" is distributed in the hope
# that it will be useful, but WITHOUT ANY WARRANTY; without even
# the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with "The Wind Instrument Acoustic Toolkit".
# If not, see <http://www.gnu.org/licenses/>.
#
# All rights reserved.

""" Transmission Matrix (TM) acoustic input impedance calculation.

    This package is used for the calculation of the frequency response of wind
    music instrument. It is based on the discretization of instrument air 
    columns into cylindrical and conical sections, with and without toneholes. 

    The following references discuss the method:
    
        1. Plitnik, G. R., & Strong, W. J. (1979). 
           Numerical method for calculating input impedances of the oboe. 
           The Journal of the Acoustical Society of America, 65(3), 816-825.

        2. Causs, R., Kergomard, J., & Lurton, X. (1984).
           Input impedance of brass musical instruments - 
	   Comparaison between experimental and numerical models. 
	   J. Acoust. Soc. Am., 75, 241-254.

    The Instrument class and CalculateImpedance functions, defined in the Inst
    module, contains the core of the methode. The Waveguides, ToneHole, and
    Radiation modules implement the transmission matrices used in the
    calculation. Boundary layer losses are taken into account.

"""

__version__ = "0.0.0.1"
__author__ = "Antoine Lefebvre"
__credits__ = "FQRNT"
__license__ = "GPLv3"

import Waveguides
from Waveguides import *

import Radiation as r
from Radiation import *

import Inst
from Inst import *

import Functions as func
from Functions import *

__all__ = []
__all__ += Waveguides.__all__
__all__ += r.__all__
__all__ += Inst.__all__
__all__ += func.__all__
