# Copyright 2008 Antoine Lefebvre
#
# This file is part of "The Wind Instrument Acoustic Toolkit".
#
# "The Wind Instrument Acoustic Toolkit" is free software:
# you can redistribute it and/or modify it under the terms of
# the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# "The Wind Instrument Acoustic Toolkit" is distributed in the hope
# that it will be useful, but WITHOUT ANY WARRANTY; without even
# the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with "The Wind Instrument Acoustic Toolkit".
# If not, see <http://www.gnu.org/licenses/>.
#
# All rights reserved.

""" B{The Wind Instrument Acoustic Toolkit}
    
    U{http://www.music.mcgill.ca/musictech/caml/wiat/}

    This toolkit consists of a package of computer programs useful for
    researchers in wind instrument musical acoustics and eventually, the 
    wind instrument designer as well. It includes both simulation and 
    measurement capabilities. Researchers from musical acoustics laboratories 
    around the world are invited to collaborate in its development to keep it 
    up to date with the latest theoretical results. The capabilities of the 
    software include:

        1. the calculation of linear input impedance from a geometry definition 
           using either a one-dimensional transmission-matrix (TM) method or 
           multimodal method (MM);

        2. optimization routines for the design of wind instrument prototypes; 

        3. processing of measurement data for comparison with simulation 
           results; 
 
        4. automatic generation of reports for easy incorporation into 
           publications and/or web sites.
        
    Other suggestions are welcome.

    Important notes:
        - Dimensions are in meters. 

    To get started, you can look at the Examples directory.

"""

__version__ = "0.1.0"
__author__ = "Antoine Lefebvre"
__credits__ = "Thanks to the U{FQRNT<http://www.fqrnt.gouv.qc.ca/>} for"+\
        " financing my doctoral studies."
__license__ = "GPLv3"

import wiat.Plot
import wiat.Reports
import wiat.Data
import wiat.util
import wiat.TM
import wiat.MM
import wiat.instruments

__all__ =  ['TM', 'MM', 'instruments']

import os
BEMDIR = os.path.join(os.path.dirname(__file__), 'data', \
    'BEM simulation results')
MEASUREMENTDIR = os.path.join(os.path.dirname(__file__), 'data', \
    'Impedance measurement data')
del os
