# Copyright 2008 Antoine Lefebvre
#
# This file is part of "The Wind Instrument Acoustic Toolkit".
#
# "The Wind Instrument Acoustic Toolkit" is free software:
# you can redistribute it and/or modify it under the terms of
# the GNU General Public License as published by the
# Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# "The Wind Instrument Acoustic Toolkit" is distributed in the hope
# that it will be useful, but WITHOUT ANY WARRANTY; without even
# the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
# See the GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with "The Wind Instrument Acoustic Toolkit".
# If not, see <http://www.gnu.org/licenses/>.
#
# All rights reserved.

""" Flutes.py - This file defines flute-like instruments.

    It contains the following instruments:

        - B{OldFlute}

          An old wooden flute. The data come from [1]. 
        
	  TODO: This instrument is still incomplete.

    References:

        1. Nederveen, C. J. (1998).
           Acoustical Aspects of Woodwind Instruments., revised edition.
           147 pages. Northern Illinois University Press.
        
"""

import wiat

_OLDFLUTEBODY = wiat.TM.CreateCylindersAndConesFromList(
    [(0.,0.0188), (0.132,0.0188), (0.340,0.0152), 
     (0.452,0.0135), (0.583,0.0112)])

_D_RADIATION = 0.0112

_OLDFLUTETONEHOLES = \
[wiat.TM.ToneHole(d=0.0117,t=0.0043,p=0.474,d_pad=0.,h_pad=0.),\
 wiat.TM.ToneHole(d=0.0112,t=0.0043,p=0.505,d_pad=0.,h_pad=0.),\
 wiat.TM.ToneHole(d=0.0102,t=0.0043,p=0.540,d_pad=0.,h_pad=0.)]

_OLDFLUTEFINGERINGS ={'C': [0,0,0],\
                     'C sharp':[0,0,1],\
                     'D': [0,1,1],\
                     'D sharp': [1,1,1],\
                     'cross':[1,0,0]}

OldFlute = wiat.TM.Instrument(
                "Nederveen old flute", _OLDFLUTEBODY,
                wiat.TM.UnflangedOpenEnd(_D_RADIATION),
                _OLDFLUTETONEHOLES, _OLDFLUTEFINGERINGS)
