import unittest
import numpy
import pylab
from wiat.TM import *
from wiat.instruments import Flutes

class TestToneHole(unittest.TestCase):
    def setUp(self):
        #self.f = numpy.arange(100,4600,1,dtype=float)
        self.f = numpy.logspace(numpy.log10(50),numpy.log10(4500),num=500)
        self.T = 25.

    def testNederveenOldFlute(self):
        " Calculate the resonance frequencies of the old flute model from Nederveen book "
        for fingering in Flutes.OldFlute.get_fingerings().keys():
            Z = CalculateImpedance(Flutes.OldFlute.set_fingering(fingering),
                    self.f,self.T)
            pylab.plot(self.f, numpy.abs(Z))
            ml = CalculateMaxima(Z, Flutes.OldFlute, self.f, self.T, 
                    number_of_maxima=1)
            print fingering, ml[0]
        pylab.legend(Flutes.OldFlute.get_fingerings().keys())
        pylab.show()
        self.failUnless(True,"dummy")

    def testSingleToneHoleCylinder(self):
        """ Calculate the resonance frequency of a cylinder with a single 
            tonehole 
        """
        I1 = Instrument("Cylinder with one tone hole",
                       [Cylinder(0.014,0.583)], UnflangedOpenEnd(0.014),
                       [ToneHole(0.0117,0.0043,0.474)],
                       {'open':[1],'closed':[0]})
        I2 = Instrument("Cylinder without tone hole",
                       [Cylinder(0.014,0.583)], UnflangedOpenEnd(0.014))
        
        Zopen = CalculateImpedance(I1.set_fingering('open'),self.f,self.T)
        MaximaOpen = CalculateMaxima(Zopen, I1, self.f, self.T, 
                number_of_maxima=1)
        Zclosed = CalculateImpedance(I1.set_fingering('closed'),self.f,self.T)
        MaximaClosed = CalculateMaxima(Zclosed, I1, self.f, self.T, 
                number_of_maxima=1)

        Zwithout = CalculateImpedance(I2,self.f,self.T)
        
        pylab.plot(self.f, numpy.abs(Zopen), self.f, numpy.abs(Zclosed), 
                self.f, numpy.abs(Zwithout))
        pylab.legend(('open','closed','without'))
        pylab.show()
                   
        c = CompareMaxima(MaximaOpen, MaximaClosed)
        print c

        self.failUnless(True,numpy.abs(c[0][2]) < 20.)
        
suite = unittest.TestSuite()
suite.addTest(TestToneHole('testNederveenOldFlute'))
suite.addTest(TestToneHole('testSingleToneHoleCylinder'))
unittest.TextTestRunner(verbosity=2).run(suite)



